summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorchouseknecht <chouseknecht@ansible.com>2015-09-21 21:08:16 +0000
committerJames Cammarata <jimi@sngx.net>2015-09-30 13:36:23 -0400
commitf4690e3bfea88ce39d01304aeab08ba979137a21 (patch)
treee55b4331f6a0df5fc06340f028a14cd824551452
parent8360a1b3f2aa24e264f2b4d10793b75182c86ddb (diff)
downloadansible-f4690e3bfea88ce39d01304aeab08ba979137a21.tar.gz
Changing tag to galaxy_tag.
-rw-r--r--lib/ansible/cli/galaxy.py10
-rw-r--r--lib/ansible/galaxy/data/metadata_template.j24
2 files changed, 7 insertions, 7 deletions
diff --git a/lib/ansible/galaxy/data/metadata_template.j2 b/lib/ansible/galaxy/data/metadata_template.j2
index cd2e7f53cd..fbcc402cf6 100644
--- a/lib/ansible/galaxy/data/metadata_template.j2
+++ b/lib/ansible/galaxy/data/metadata_template.j2
@@ -28,14 +28,14 @@ galaxy_info:
# - {{ version }}
{%- endfor %}
{%- endfor %}
- tags: []
+ galaxy_tags: []
# List tags for your role here, one per line. A tag is
# a keyword that describes and categorizes the role.
# Users find roles by searching for tags. Be sure to
# remove the '[]' above if you add dependencies
# to this list.
#
- # NOTE: A tag is limted to a single word comprised of
+ # NOTE: A tag is limited to a single word comprised of
# alphanumeric characters. Maximum 20 tags per role.
dependencies: []
# List your role dependencies here, one per line.
diff --git a/lib/ansible/cli/galaxy.py b/lib/ansible/cli/galaxy.py
index ae3e38959f..7468f72f89 100644
--- a/lib/ansible/cli/galaxy.py
+++ b/lib/ansible/cli/galaxy.py
@@ -85,9 +85,9 @@ class GalaxyCLI(CLI):
elif self.action == "search":
self.parser.add_option('-P', '--platforms', dest='platforms',
help='list of OS platforms to filter by')
- self.parser.add_option('-T', '--tags', dest='tags',
- help='list of tags to filter by')
- self.parser.set_usage("usage: %prog search [<search_term>] [-T <tag1,tag2>] [-P platform]")
+ self.parser.add_option('-T', '--galaxy-tags', dest='tags',
+ help='list of galaxy tags to filter by')
+ self.parser.set_usage("usage: %prog search [<search_term>] [-T <galaxy_tag1,galaxy_tag2>] [-P platform]")
# options that apply to more than one action
if self.action != "init":
@@ -248,8 +248,8 @@ class GalaxyCLI(CLI):
if dir == "meta":
# create a skeleton meta/main.yml with a valid galaxy_info
# datastructure in place, plus with all of the available
# tags/platforms included (but commented out) and the
# dependencies section
platforms = []
if not offline and self.api:
platforms = self.api.get_list("platforms") or []
@@ -248,8 +248,8 @@ class GalaxyCLI(CLI):
# create a skeleton meta/main.yml with a valid galaxy_info
# datastructure in place, plus with all of the available
- # tags/platforms included (but commented out) and the
- # dependencies section
+ # platforms included (but commented out), the galaxy_tags
+ # list, and the dependencies section
platforms = []
if not offline and self.api: